Skip to contents

Runs the kth slice of RSCABS

Usage

RSCABK(x.i.j, n.i.j, m.i, TestK, test.type)

Arguments

x.i.j

matrix containing the number of observed "successes" for replicate i on treatment j.

n.i.j

matrix containing the number of observations for replicate i on treatment j.

m.i

matrix of number units in each treatment/replicate combination.

TestK

The kth severity score being tested.

test.type

Indicate the type of analysis to be performed. Use "RS" to select the Rao-Scott adjustment to the Cochran-Armitage test and "CA" to ignore the adjustment.

Value

Returns a list with the following values:

Response

The endpoint that is being tested.

Treatment

The treatment level.

R-Score

The severity score from the histology.

Statistic

The test statistic corresponding to that row's endpoint treatment level and R-Score.

P-Value

The corresponding p-value

Signif

The significance flag where the cutoffs for stars and dot are 0, 1e-04, 0.001, 0.01,0.05,1.

Author

Joe Swintek