Skip to contents

Aggregate Individual Fish Records to Summarized Format (simple without tidyverse version)

Usage

aggregate_from_individual_simple(
  data,
  treatment_col = "tmt",
  replicate_col = "tank",
  score_col = "score",
  total_col = "total",
  all_scores = NULL
)

Arguments

data

A data frame containing individual fish records

treatment_col

Name of the column containing treatment groups (default: "tmt")

replicate_col

Name of the column containing tank/replicate IDs (default: "tank")

score_col

Name of the column containing scores (default: "score")

total_col

Name of the column to be created for total counts (default: "total")

all_scores

Optional vector of all score categories to include in the result, even if they have zero occurrences (default: NULL, which uses unique values in data)

Value

A data frame with aggregated counts per replicate