Skip to contents

This function calculates the standard error (SE) of a lognormally distributed variable based on the mean (mu) and the standard error of the logarithm (se).

Usage

backCalcSE(se, mu, approximate = FALSE)

Arguments

se

The standard error of the logarithm.

mu

The mean of the logarithm.

approximate

Logical. If TRUE, uses an approximation; otherwise, calculates based on the variance of the lognormal distribution.

Value

The back-calculated standard error.

Examples

backCalcSE(se = 0.1, mu = 0)
#> [1] 0.100753
backCalcSE(se = 0.1, mu = 0, approximate = TRUE)
#> [1] 0.1