Skip to contents

Function to get the comparison groups for Williams test or other.

Usage

getComparison(object, test = c("trend", "many-to-one"))

Arguments

object

test result from different type of tests

test

the test used, either a trend test or a many-to-one test