Returns the model name and description for one or more fitted model names.
Value
Character vector of model names and descriptions. For NULL, returns all available models. For vector input, returns corresponding descriptions for each name. Special handling for LN.* and LL.* models.
Examples
getModelName() # Returns all available model names and descriptions
#> Log-logistic (ED50 as parameter) with lower limit at 0 and upper limit at 1
#> (2 parameters)
#> In 'drc': LL.2
#>
#> Log-logistic (ED50 as parameter) with lower limit at 0
#> (3 parameters)
#> In 'drc': LL.3
#>
#> Log-logistic (ED50 as parameter) with upper limit at 1
#> (3 parameters)
#> In 'drc': LL.3u
#>
#> Log-logistic (ED50 as parameter)
#> (4 parameters)
#> In 'drc': LL.4
#>
#> Generalized log-logistic (ED50 as parameter)
#> (5 parameters)
#> In 'drc': LL.5
#>
#> Weibull (type 1) with lower limit at 0 and upper limit at 1
#> (2 parameters)
#> In 'drc': W1.2
#>
#> Weibull (type 1) with lower limit at 0
#> (3 parameters)
#> In 'drc': W1.3
#>
#> Weibull (type 1)
#> (4 parameters)
#> In 'drc': W1.4
#>
#> Weibull (type 2) with lower limit at 0 and upper limit at 1
#> (2 parameters)
#> In 'drc': W2.2
#>
#> Weibull (type 2) with lower limit at 0
#> (3 parameters)
#> In 'drc': W2.3
#>
#> Weibull (type 2)
#> (4 parameters)
#> In 'drc': W2.4
#>
#> Brain-Cousens (hormesis) with lower limit fixed at 0
#> (4 parameters)
#> In 'drc': BC.4
#>
#> Brain-Cousens (hormesis)
#> (5 parameters)
#> In 'drc': BC.5
#>
#> Log-logistic (log(ED50) as parameter) with lower limit at 0 and upper limit at 1
#> (2 parameters)
#> In 'drc': LL2.2
#>
#> Log-logistic (log(ED50) as parameter) with lower limit at 0
#> (3 parameters)
#> In 'drc': LL2.3
#>
#> Log-logistic (log(ED50) as parameter) with upper limit at 1
#> (3 parameters)
#> In 'drc': LL2.3u
#>
#> Log-logistic (log(ED50) as parameter)
#> (4 parameters)
#> In 'drc': LL2.4
#>
#> Generalised log-logistic (log(ED50) as parameter)
#> (5 parameters)
#> In 'drc': LL2.5
#>
#> Asymptotic regression with lower limit at 0
#> (2 parameters)
#> In 'drc': AR.2
#>
#> Shifted asymptotic regression
#> (3 parameters)
#> In 'drc': AR.3
#>
#> Michaelis-Menten
#> (2 parameters)
#> In 'drc': MM.2
#>
#> Shifted Michaelis-Menten
#> (3 parameters)
#> In 'drc': MM.3
#>
#> [1] "LL.2: Log-logistic (ED50 as parameter) with lower limit at 0 and upper limit at 1"
#> [2] "LL.3: Log-logistic (ED50 as parameter) with lower limit at 0"
#> [3] "LL.3u: Log-logistic (ED50 as parameter) with upper limit at 1"
#> [4] "LL.4: Log-logistic (ED50 as parameter)"
#> [5] "LL.5: Generalized log-logistic (ED50 as parameter)"
#> [6] "W1.2: Weibull (type 1) with lower limit at 0 and upper limit at 1"
#> [7] "W1.3: Weibull (type 1) with lower limit at 0"
#> [8] "W1.4: Weibull (type 1)"
#> [9] "W2.2: Weibull (type 2) with lower limit at 0 and upper limit at 1"
#> [10] "W2.3: Weibull (type 2) with lower limit at 0"
#> [11] "W2.4: Weibull (type 2)"
#> [12] "BC.4: Brain-Cousens (hormesis) with lower limit fixed at 0"
#> [13] "BC.5: Brain-Cousens (hormesis)"
#> [14] "LL2.2: Log-logistic (log(ED50) as parameter) with lower limit at 0 and upper limit at 1"
#> [15] "LL2.3: Log-logistic (log(ED50) as parameter) with lower limit at 0"
#> [16] "LL2.3u: Log-logistic (log(ED50) as parameter) with upper limit at 1"
#> [17] "LL2.4: Log-logistic (log(ED50) as parameter)"
#> [18] "LL2.5: Generalised log-logistic (log(ED50) as parameter)"
#> [19] "AR.2: Asymptotic regression with lower limit at 0"
#> [20] "AR.3: Shifted asymptotic regression"
#> [21] "MM.2: Michaelis-Menten"
#> [22] "MM.3: Shifted Michaelis-Menten"
getModelName("LL.2") # Returns description for LL.2
#> [1] "LL.2: 2-parameter Log-logistic (ED50 as parameter) with lower limit at 0 and upper limit at 1"
getModelName(c("LL.2", "LN.4")) # Returns descriptions for multiple models
#> [1] "LL.2: 2-parameter Log-logistic (ED50 as parameter) with lower limit at 0 and upper limit at 1"
#> [2] "LN.4: 4-parameter log-normal"