ECx calculation together with normalized width proposed by EFSA SO.
Source:R/drc_Helper.R
mselect.ED.RdECx calculation together with normalized width proposed by EFSA SO.
Usage
mselect.ED(modList, respLev = c(10, 20, 50), trend = "Decrease", ...)