This function generates a scatter plot of response against dose on a log1p scale.
Usage
prelimPlot2(
testdata,
ylab = "Response",
xlab = "Test Concentration [nominal, mg a.s./L]",
title = "Measured Variable",
dose_col = "Dose",
response_col = "Response"
)Arguments
- testdata
A data frame containing the dose and response data.
- ylab
A string for the y-axis label. Default is "Response".
- xlab
A string for the x-axis label. Default is
"Test Concentration [nominal, mg a.s./L]".- title
A string for the plot title. Default is "Measured Variable".
- dose_col
name of the dose column, default being "Dose".
- response_col
name of the response column.