Skip to contents

This function generates a scatter plot of response against nominal dose.

Usage

prelimPlot3(
  testdata,
  ylab = "Response",
  xlab = "Test Concentration [nominal, mg a.s./L]",
  title = "Measured Variable",
  a = 1.96,
  dose_col = "Dose",
  response_col = "Response"
)

Arguments

testdata

A data frame containing the dose and response data.

ylab

A string for the y-axis label. Default is "Response".

xlab

A string for the x-axis label. Default is "Test Concentration [nominal, mg a.s./L]".

title

A string for the plot title. Default is "Measured Variable".

a

the quantile for corresponding CI for mean. default is qnorm(0.975).

dose_col

name of the dose column, default being "Dose".

response_col

name of the response column.

Value

A ggplot object.