This function provides a custom print method for objects of class drcComp.
It prints the Comparison and EFSA components of the object.
Usage
# S3 method for class 'drcComp'
print(x, ...)This function provides a custom print method for objects of class drcComp.
It prints the Comparison and EFSA components of the object.
# S3 method for class 'drcComp'
print(x, ...)