Skip to contents

This function performs a rank transformation on the data using Blom's method, which is equivalent to the SAS PROC RANK with NORMAL=BLOM and TIES=MEAN options. The transformation applies the formula (r-3/8)/(n+1/4) where r is the rank and n is the sample size.

Usage

rankTransform(Data, VecName)

Arguments

Data

A data frame containing the variable to be transformed

VecName

The name of the variable in the data frame to be transformed

Value

A data frame with an additional column 'TransformedResponse' containing the rank-transformed values

Examples

test_data <- data.frame(Value = c(5, 2, 7, 2, 9, 3))
transformed_data <- rankTransform(test_data, "Value")