Skip to contents

Steps through the severity score for a given effect

Usage

stepKRSCABS(Effect, Data.Prep, Treatment, Replicate, test.type)

Arguments

Effect

Endpoint being tested.

Data.Prep

Data prepared by prepDataRSCABS.

Treatment

Name of the treatment variable.

Replicate

Name of the replicate variable.

test.type

Indicate the type of analysis to be performed. Use "RS" to select the Rao-Scott adjustment to the Cochran-Armitage test and "CA" to ignore the adjustment.

Value

Results.Effect

Results.Effect

An intermediary step for results.

Details

An internal function for stepping through each severity score of an endpoint.

Author

Joe Swintek