Internal function to perform Tarone test with trend removal and calculate phi
Source:R/overdispersion_binom.R
tarone_with_trend_removal.RdInternal function to perform Tarone test with trend removal and calculate phi
R/overdispersion_binom.R
tarone_with_trend_removal.RdInternal function to perform Tarone test with trend removal and calculate phi