Assigns qualitative ratings to normalized width values of confidence intervals
based on predefined thresholds.
Arguments
- x
Numeric vector of normalized width values to be rated
Value
Character vector of ratings with the following categories:
Examples
# Basic examples
ECx_rating(c(0.1, 0.3, 0.7, 1.5, 2.5, NA))
#> [1] "Excellent" "Good" "Fair" "Poor" "Bad"
#> [6] "Not defined"
# Example with typical normalized widths
nw_values <- c(0.15, 0.45, 0.95, 1.8, 2.5)
ECx_rating(nw_values)
#> [1] "Excellent" "Good" "Fair" "Poor" "Bad"