This function creates a standardized output from different Dunnett test implementations.
Usage
broom_dunnett(
x,
method = c("Dunnett_multcomp", "Dunnett_DescTools", "Dunnett_PMCMRplus"),
...
)Arguments
- x
A formula object specifying the response variable and the factor for which the test is to be performed, or an object of class 'aov' or 'lm'.
- method
Character string specifying which implementation of Dunnett test to use: "Dunnett_multcomp" (default) for multcomp implementation, "Dunnett_DescTools" for DescTools implementation, or "Dunnett_PMCMRplus" for PMCMRplus implementation, do not use this one in general as it does not return complete information.
- ...
Additional arguments passed to the underlying test functions.
Value
A data frame with standardized test results containing:
- comparison
The comparison being made
- estimate
The estimated difference between groups
- p.value
The p-value for the test
- conf.low
Lower bound of the confidence interval
- conf.high
Upper bound of the confidence interval
- method
The method used for the test