Function to get the comparison groups for Williams test or other.
Source:R/wiiliams_JT.R
getComparison.RdFunction to get the comparison groups for Williams test or other.
Usage
getComparison(object, test = c("trend", "many-to-one"))R/wiiliams_JT.R
getComparison.RdFunction to get the comparison groups for Williams test or other.
getComparison(object, test = c("trend", "many-to-one"))