Obtain Endpoint (NOEC) according to a series of p-values
Usage
getEndpoint(pvals, doses = c("Control", "B", "C", "D"), procedure = "stepDown")Details
If all p-values are NA, it initializes them to zeros. If there are fewer p-values than doses, it pads the p-values with zeros.It checks which doses are significant by comparing the p-values to a threshold (0.05).Depending on the specified procedure, it either steps down from the highest dose to find the NOEC or steps up from the lowest dose..