This function calculates the mean response, standard deviation, percent inhibition, and coefficient of variation for each dose level.
Value
A data frame summarizing the mean, standard deviation, percent inhibition, and coefficient of variation for each dose.
Examples
# Sample data frame
testdata <- data.frame(Dose = c(0, 1, 2, 3, 0, 1, 2, 3),
Response = c(10, 20, 30, 40, 12, 22, 32, 42))
# Create the summary
summary_result <- prelimSummary(testdata, dose_col = "Dose", response_col = "Response")
print(summary_result)
#> # A tibble: 4 × 5
#> Dose Mean SD `% Inhibition` CV
#> <dbl> <dbl> <dbl> <dbl> <dbl>
#> 1 0 11 1.41 0 12.9
#> 2 1 21 1.41 -90.9 6.73
#> 3 2 31 1.41 -182. 4.56
#> 4 3 41 1.41 -273. 3.45