Function to test for overdispersion in binomial data using glm approach
Source:R/stepdown_binom.R
test_overdispersion.RdFunction to test for overdispersion in binomial data using glm approach
R/stepdown_binom.R
test_overdispersion.RdFunction to test for overdispersion in binomial data using glm approach